"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class StepFormat(str, Enum):
    r"""An enumeration."""
    JSON = 'json'
    MARKDOWN = 'markdown'
    HTML = 'html'
