"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class LLMEvaluationCriteriaType(str, Enum):
    r"""An enumeration."""
    DEFAULT = 'DEFAULT'
    CUSTOM = 'CUSTOM'
    PROJECTION = 'PROJECTION'
