"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class LLMEvaluationErrorType(str, Enum):
    r"""An enumeration."""
    USER = 'USER'
    SYSTEM = 'SYSTEM'
