"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class OrganizationTier(str, Enum):
    r"""Represents the different tiers an organization can have."""
    INTERNAL = 'internal'
    POC = 'poc'
    ENTERPRISE = 'enterprise'
    TEAM = 'team'
