"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class PassFailUnsureRubricScaleValues(str, Enum):
    r"""An enumeration."""
    PASS = 'PASS'
    FAIL = 'FAIL'
    UNSURE = 'UNSURE'
    NOT_APPLICABLE = 'NOT_APPLICABLE'
    ERROR = 'ERROR'
